@@ -209,6 +209,13 @@ class Resource(Generic[T]):
         def locator(self) -> Resource.Locator:
             return Resource.Locator(self.namespace, self.name)
 
+        def with_default_namespace(self, namespace: str) -> Resource.URI:
+            """
+            Return a copy of this URI with the given namespace if the namespace is not set.
+            """
+
+            return Resource.URI(self.apiVersion, self.kind, self.namespace or namespace, self.name)
+
     @JsonConverter.using_classmethods(serialize="__str__", deserialize="of")
     @dataclass(frozen=True)
     class Type:
@@ -227,6 +234,10 @@ class Resource(Generic[T]):
             apiVersion, kind = s.rpartition("/")[::2]
             return cls(apiVersion, kind)
 
+        @classmethod
+        def uri(self, namespace: str | None, name: str) -> Resource.URI:
+            return Resource.URI(self.apiVersion, self.kind, namespace, name)
+
     @JsonConverter.using_classmethods(serialize="__str__", deserialize="of")
     @dataclass(frozen=True)
     class Locator:
@@ -248,6 +259,10 @@ class Resource(Generic[T]):
             namespace, name = s.rpartition("/")[::2]
             return cls(namespace or None, name)
 
+        @classmethod
+        def uri(self, apiVersion: str, kind: str, name: str) -> Resource.URI:
+            return Resource.URI(apiVersion, kind, self.namespace, name)
+
     @dataclass(frozen=True)
     class Metadata:
         namespace: str | None
